# pmkoalas: A Process Mining Project
[![Python 3.[9,10,11]](https://github.com/AdamBanham/koalas/actions/workflows/python-version.yml/badge.svg?branch=main)](https://github.com/AdamBanham/koalas/actions/workflows/python-version.yml)   [![Testing](https://github.com/AdamBanham/koalas/actions/workflows/python-unittests.yml/badge.svg)](https://github.com/AdamBanham/koalas/actions/workflows/python-unittests.yml)


`pmkoalas` provides data structures for process mining research in a well-organized pythonic style.

# Development
To install the library as a local copy, such that edits to source will be automatically translated into your intercepter use the following command:
`py -m pip install -e .[dev]`

## Test
To run tests use the following command
`py -m pip install -e .[dev] && py -m unittest`

# Values of the team

## Postel's law
[https://en.wikipedia.org/wiki/Jon_Postel](cite)
Perhaps his most famous legacy is from RFC760, which includes a robustness principle often called Postel's law: "an implementation should be conservative in its sending behavior, and liberal in its receiving behavior" (reworded in RFC 1122 as "Be liberal in what you accept, and conservative in what you send").
